Software development kit for utilizing Curi Bio data files and online databases

.. image:: https://img.shields.io/pypi/v/curibio.sdk.svg
    :target: https://pypi.org/project/curibio.sdk/

.. image:: https://pepy.tech/badge/curibio.sdk
  :target: https://pepy.tech/project/curibio.sdk

.. image:: https://img.shields.io/pypi/pyversions/curibio.sdk.svg
    :target: https://pypi.org/project/curibio.sdk/

.. image:: https://github.com/CuriBio/curibio.sdk/workflows/Dev/badge.svg?branch=development
   :alt: Development Branch Build

.. image:: https://codecov.io/gh/CuriBio/curibio.sdk/branch/development/graph/badge.svg
  :target: https://codecov.io/gh/CuriBio/curibio.sdk

.. image:: https://readthedocs.org/projects/curibiosdk/badge/?version=stable
 :target: https://curibiosdk.readthedocs.io/en/stable/?badge=stable
 :alt: Documentation Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black

.. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit


Launch an online Jupyter notebook

.. image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/curibio/curibio.sdk/main?filepath=intro.ipynb